# Contributors
Thanks to the following individuals for providing pull requests, feedback, bug reports, answering
questions, and other contributions that have helped to improve pyinaturalist:     

* [AE Hamrick](https://github.com/AEHamrick)
* [Felipe S Barros](https://github.com/FelipeSBarros)
* [Ken-ichi Ueda](https://github.com/kueda/)
* [Matt Muir](https://forum.inaturalist.org/u/muir)
* [Patrick Leary](https://github.com/pleary)
* [Peter Desmet](https://github.com/peterdesmet)
* [pisum](https://forum.inaturalist.org/u/pisum)
* [Sam R](https://github.com/samtreesandbushes)
* [SDJ Brown](https://github.com/sdjbrown)
* [Stijn Van Hoey](https://github.com/stijnvanhoey)
* [Dr. Tom August](https://github.com/AugustT)
* [Will Kuhn](https://github.com/willkuhn)
